Mosaic tiles#
There is a set of tiles enabled by default in the Mosaic editor.
Table of contents
Rich text
Navigation
Embed
Title
Summary
Text
Custom layout
Discussion
Document byline
Related items
Keywords
Content listing
Existing content
RSS
Table of contents#
Display a table of contents from the page headers.
Rich text#
Rich text tiles can be used in your layout to have freeform content that can be edited through the TinyMCE editor.
See also TinyMCE customization.
Embed#
Paste a URL here to embed external multimedia content. Supported sites can be found at noembed.com.
Title#
Display the title of the current item.
Summary#
Display the description from the current item.
Text#
Display the main text field from the current item.
Discussion#
Displays comments associated with the current item.
Content listing#
Display the results of a saved search of the site content.
Existing content#
A tile which displays the default view of a content object.
RSS feed#
Show the items from a content feed like plone.org/RSS.
Document byline#
Shows the document byline with author name and date.
Keywords#
Display the keywords defined in the categorization tab of this item.